@@ -1,5 +1,4 @@
+"""Entry for ``python -m bumplus ...``."""
 from __future__ import absolute_import, division, print_function
 
-__metaclass__ = type
-
 __import__("bumplus").main()
