@@ -1,5 +1,4 @@
+"""Version number of Bumplus."""
 from __future__ import absolute_import, division, print_function
 
-__metaclass__ = type
-
-__version__ = "0.9.0"
+__version__ = "0.10.0"
